Revisions

Struct Revisions 

pub struct Revisions {
    pub parent_a: String,
    pub parent_b: String,
    pub merged: String,
}
Commit identities recorded with one three-worktree observation.

Fields

parent_a: String

First-parent commit as a canonical full Git object id.

parent_b: String

Second-parent commit as a canonical full Git object id.

merged: String

Speculative merge commit as a canonical full Git object id.