pub struct Revisions {
pub parent_a: String,
pub parent_b: String,
pub merged: String,
}Expand description
Commit identities recorded with one three-worktree observation.
Fields
parent_a: StringFirst-parent commit as a canonical full Git object id.
parent_b: StringSecond-parent commit as a canonical full Git object id.
merged: StringSpeculative merge commit as a canonical full Git object id.